summaryrefslogtreecommitdiffstats
path: root/libkcal
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /libkcal
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkcal')
-rw-r--r--libkcal/alarm.cpp8
-rw-r--r--libkcal/alarm.h8
-rw-r--r--libkcal/attachmenthandler.cpp58
-rw-r--r--libkcal/attachmenthandler.h44
-rw-r--r--libkcal/calendar.cpp20
-rw-r--r--libkcal/calendarresources.cpp8
-rw-r--r--libkcal/calendarresources.h26
-rw-r--r--libkcal/confirmsavedialog.cpp4
-rw-r--r--libkcal/confirmsavedialog.h2
-rw-r--r--libkcal/icaldrag.cpp4
-rw-r--r--libkcal/icaldrag.h2
-rw-r--r--libkcal/icalformat.cpp6
-rw-r--r--libkcal/icalformatimpl.cpp132
-rw-r--r--libkcal/icalformatimpl.h14
-rw-r--r--libkcal/incidence.h4
-rw-r--r--libkcal/recurrence.h2
-rw-r--r--libkcal/recurrencerule.h4
-rw-r--r--libkcal/resourcecached.cpp4
-rw-r--r--libkcal/resourcecachedconfig.cpp8
-rw-r--r--libkcal/resourcecachedconfig.h4
-rw-r--r--libkcal/resourcecalendar.h6
-rw-r--r--libkcal/resourcelocalconfig.cpp4
-rw-r--r--libkcal/resourcelocalconfig.h2
-rw-r--r--libkcal/resourcelocaldirconfig.cpp4
-rw-r--r--libkcal/resourcelocaldirconfig.h2
-rw-r--r--libkcal/scheduler.cpp6
-rw-r--r--libkcal/vcaldrag.cpp4
-rw-r--r--libkcal/vcaldrag.h2
-rw-r--r--libkcal/versit/readme.txt4
29 files changed, 198 insertions, 198 deletions
diff --git a/libkcal/alarm.cpp b/libkcal/alarm.cpp
index a860072d..eed17afe 100644
--- a/libkcal/alarm.cpp
+++ b/libkcal/alarm.cpp
@@ -29,8 +29,8 @@
using namespace KCal;
-Alarm::Alarm(Incidence *tqparent)
- : mParent(tqparent),
+Alarm::Alarm(Incidence *parent)
+ : mParent(parent),
mType(Invalid),
mDescription(""), // to make operator==() not fail
mFile(""), // to make operator==() not fail
@@ -476,9 +476,9 @@ Duration Alarm::endOffset() const
return (mHasTime || !mEndOffset) ? Duration( 0 ) : mOffset;
}
-void Alarm::setParent( Incidence *tqparent )
+void Alarm::setParent( Incidence *parent )
{
- mParent = tqparent;
+ mParent = parent;
}
void Alarm::customPropertyUpdated()
diff --git a/libkcal/alarm.h b/libkcal/alarm.h
index fc85e96f..efe047d6 100644
--- a/libkcal/alarm.h
+++ b/libkcal/alarm.h
@@ -52,7 +52,7 @@ class LIBKCAL_EXPORT Alarm : public CustomProperties
/**
Construct a new alarm with variables initialized to "sane" values.
*/
- explicit Alarm( Incidence *tqparent );
+ explicit Alarm( Incidence *parent );
/**
Destruct Alarm object.
*/
@@ -342,13 +342,13 @@ class LIBKCAL_EXPORT Alarm : public CustomProperties
bool enabled() const;
/**
- Set the alarm's tqparent incidence.
+ Set the alarm's parent incidence.
*/
void setParent( Incidence * );
/**
- Get the alarm's tqparent incidence.
+ Get the alarm's parent incidence.
*/
- Incidence *tqparent() const { return mParent; }
+ Incidence *parent() const { return mParent; }
protected:
/**
diff --git a/libkcal/attachmenthandler.cpp b/libkcal/attachmenthandler.cpp
index a465a774..009c5778 100644
--- a/libkcal/attachmenthandler.cpp
+++ b/libkcal/attachmenthandler.cpp
@@ -47,7 +47,7 @@
namespace KCal {
-Attachment *AttachmentHandler::find( TQWidget *tqparent, const TQString &attachmentName,
+Attachment *AttachmentHandler::find( TQWidget *parent, const TQString &attachmentName,
Incidence *incidence )
{
if ( !incidence ) {
@@ -69,15 +69,15 @@ Attachment *AttachmentHandler::find( TQWidget *tqparent, const TQString &attachm
if ( !a ) {
KMessageBox::error(
- tqparent,
+ parent,
i18n( "No attachment named \"%1\" found in the incidence." ).tqarg( attachmentName ) );
return 0;
}
if ( a->isUri() ) {
- if ( !KIO::NetAccess::exists( a->uri(), true, tqparent ) ) {
+ if ( !KIO::NetAccess::exists( a->uri(), true, parent ) ) {
KMessageBox::sorry(
- tqparent,
+ parent,
i18n( "The attachment \"%1\" is a web link that is inaccessible from this computer. " ).
arg( KURL::decode_string( a->uri() ) ) );
return 0;
@@ -86,7 +86,7 @@ Attachment *AttachmentHandler::find( TQWidget *tqparent, const TQString &attachm
return a;
}
-Attachment *AttachmentHandler::find( TQWidget *tqparent,
+Attachment *AttachmentHandler::find( TQWidget *parent,
const TQString &attachmentName, const TQString &uid )
{
if ( uid.isEmpty() ) {
@@ -99,16 +99,16 @@ Attachment *AttachmentHandler::find( TQWidget *tqparent,
Incidence *incidence = cal->incidence( uid );
if ( !incidence ) {
KMessageBox::error(
- tqparent,
+ parent,
i18n( "The incidence that owns the attachment named \"%1\" could not be found. "
"Perhaps it was removed from your calendar?" ).tqarg( attachmentName ) );
return 0;
}
- return find( tqparent, attachmentName, incidence );
+ return find( parent, attachmentName, incidence );
}
-Attachment *AttachmentHandler::find( TQWidget *tqparent, const TQString &attachmentName,
+Attachment *AttachmentHandler::find( TQWidget *parent, const TQString &attachmentName,
ScheduleMessage *message )
{
if ( !message ) {
@@ -118,13 +118,13 @@ Attachment *AttachmentHandler::find( TQWidget *tqparent, const TQString &attachm
Incidence *incidence = dynamic_cast<Incidence*>( message->event() );
if ( !incidence ) {
KMessageBox::error(
- tqparent,
+ parent,
i18n( "The calendar invitation stored in this email message is broken in some way. "
"Unable to continue." ) );
return 0;
}
- return find( tqparent, attachmentName, incidence );
+ return find( parent, attachmentName, incidence );
}
static KTempFile *s_tempFile = 0;
@@ -157,7 +157,7 @@ static KURL tempFileForAttachment( Attachment *attachment )
return url;
}
-bool AttachmentHandler::view( TQWidget *tqparent, Attachment *attachment )
+bool AttachmentHandler::view( TQWidget *parent, Attachment *attachment )
{
if ( !attachment ) {
return false;
@@ -174,7 +174,7 @@ bool AttachmentHandler::view( TQWidget *tqparent, Attachment *attachment )
} else {
stat = false;
KMessageBox::error(
- tqparent,
+ parent,
i18n( "Unable to create a temporary file for the attachment." ) );
}
delete s_tempFile;
@@ -183,31 +183,31 @@ bool AttachmentHandler::view( TQWidget *tqparent, Attachment *attachment )
return stat;
}
-bool AttachmentHandler::view( TQWidget *tqparent, const TQString &attachmentName, Incidence *incidence )
+bool AttachmentHandler::view( TQWidget *parent, const TQString &attachmentName, Incidence *incidence )
{
- return view( tqparent, find( tqparent, attachmentName, incidence ) );
+ return view( parent, find( parent, attachmentName, incidence ) );
}
-bool AttachmentHandler::view( TQWidget *tqparent, const TQString &attachmentName, const TQString &uid )
+bool AttachmentHandler::view( TQWidget *parent, const TQString &attachmentName, const TQString &uid )
{
- return view( tqparent, find( tqparent, attachmentName, uid ) );
+ return view( parent, find( parent, attachmentName, uid ) );
}
-bool AttachmentHandler::view( TQWidget *tqparent, const TQString &attachmentName,
+bool AttachmentHandler::view( TQWidget *parent, const TQString &attachmentName,
ScheduleMessage *message )
{
- return view( tqparent, find( tqparent, attachmentName, message ) );
+ return view( parent, find( parent, attachmentName, message ) );
}
-bool AttachmentHandler::saveAs( TQWidget *tqparent, Attachment *attachment )
+bool AttachmentHandler::saveAs( TQWidget *parent, Attachment *attachment )
{
// get the saveas file name
- TQString saveAsFile = KFileDialog::getSaveFileName( attachment->label(), TQString(), tqparent,
+ TQString saveAsFile = KFileDialog::getSaveFileName( attachment->label(), TQString(), parent,
i18n( "Save Attachment" ) );
if ( saveAsFile.isEmpty() ||
( TQFile( saveAsFile ).exists() &&
( KMessageBox::warningYesNo(
- tqparent,
+ parent,
i18n( "%1 already exists. Do you want to overwrite it?").
arg( saveAsFile ) ) == KMessageBox::No ) ) ) {
return false;
@@ -223,12 +223,12 @@ bool AttachmentHandler::saveAs( TQWidget *tqparent, Attachment *attachment )
if ( tempUrl.isValid() ) {
stat = KIO::NetAccess::file_copy( tempUrl, KURL( saveAsFile ), -1, true );
if ( !stat && KIO::NetAccess::lastError() ) {
- KMessageBox::error( tqparent, KIO::NetAccess::lastErrorString() );
+ KMessageBox::error( parent, KIO::NetAccess::lastErrorString() );
}
} else {
stat = false;
KMessageBox::error(
- tqparent,
+ parent,
i18n( "Unable to create a temporary file for the attachment." ) );
}
delete s_tempFile;
@@ -237,21 +237,21 @@ bool AttachmentHandler::saveAs( TQWidget *tqparent, Attachment *attachment )
return stat;
}
-bool AttachmentHandler::saveAs( TQWidget *tqparent, const TQString &attachmentName,
+bool AttachmentHandler::saveAs( TQWidget *parent, const TQString &attachmentName,
Incidence *incidence )
{
- return saveAs( tqparent, find( tqparent, attachmentName, incidence ) );
+ return saveAs( parent, find( parent, attachmentName, incidence ) );
}
-bool AttachmentHandler::saveAs( TQWidget *tqparent, const TQString &attachmentName, const TQString &uid )
+bool AttachmentHandler::saveAs( TQWidget *parent, const TQString &attachmentName, const TQString &uid )
{
- return saveAs( tqparent, find( tqparent, attachmentName, uid ) );
+ return saveAs( parent, find( parent, attachmentName, uid ) );
}
-bool AttachmentHandler::saveAs( TQWidget *tqparent, const TQString &attachmentName,
+bool AttachmentHandler::saveAs( TQWidget *parent, const TQString &attachmentName,
ScheduleMessage *message )
{
- return saveAs( tqparent, find( tqparent, attachmentName, message ) );
+ return saveAs( parent, find( parent, attachmentName, message ) );
}
}
diff --git a/libkcal/attachmenthandler.h b/libkcal/attachmenthandler.h
index 5bbeef46..6116f15a 100644
--- a/libkcal/attachmenthandler.h
+++ b/libkcal/attachmenthandler.h
@@ -49,128 +49,128 @@ namespace AttachmentHandler {
/**
Finds the attachment in the user's calendar, by @p attachmentName and @p incidence.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachmentName is the name of the attachment
@param incidence is a pointer to a valid Incidence object containing the attachment.
@return a pointer to the Attachment object located; 0 if no such attachment could be found.
*/
- Attachment *find( TQWidget *tqparent, const TQString &attachmentName, Incidence *incidence );
+ Attachment *find( TQWidget *parent, const TQString &attachmentName, Incidence *incidence );
/**
Finds the attachment in the user's calendar, by @p attachmentName and a scheduler message;
in other words, this function is intended to retrieve attachments from calendar invitations.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachmentName is the name of the attachment
@param message is a pointer to a valid ScheduleMessage object containing the attachment.
@return a pointer to the Attachment object located; 0 if no such attachment could be found.
*/
- Attachment *find( TQWidget *tqparent, const TQString &attachmentName, ScheduleMessage *message );
+ Attachment *find( TQWidget *parent, const TQString &attachmentName, ScheduleMessage *message );
/**
Finds the attachment in the user's calendar, by @p attachmentName and @p uid.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachmentName is the name of the attachment
@param uid is a TQString containing a UID of the incidence containing the attachment.
@return a pointer to the Attachment object located; 0 if no such attachment could be found.
*/
- Attachment *find( TQWidget *tqparent, const TQString &attachmentName, const TQString &uid );
+ Attachment *find( TQWidget *parent, const TQString &attachmentName, const TQString &uid );
/**
Launches a viewer on the specified attachment.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachment is a pointer to a valid Attachment object.
@return true if the viewer program successfully launched; false otherwise.
*/
- bool view( TQWidget *tqparent, Attachment *attachment );
+ bool view( TQWidget *parent, Attachment *attachment );
/**
Launches a viewer on the specified attachment.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachmentName is the name of the attachment
@param incidence is a pointer to a valid Incidence object containing the attachment.
@return true if the attachment could be found and the viewer program successfully launched;
false otherwise.
*/
- bool view( TQWidget *tqparent, const TQString &attachmentName, Incidence *incidence );
+ bool view( TQWidget *parent, const TQString &attachmentName, Incidence *incidence );
/**
Launches a viewer on the specified attachment.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachmentName is the name of the attachment
@param uid is a TQString containing a UID of the incidence containing the attachment.
@return true if the attachment could be found and the viewer program successfully launched;
false otherwise.
*/
- bool view( TQWidget *tqparent, const TQString &attachmentName, const TQString &uid );
+ bool view( TQWidget *parent, const TQString &attachmentName, const TQString &uid );
/**
Launches a viewer on the specified attachment.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachmentName is the name of the attachment
@param message is a pointer to a valid ScheduleMessage object containing the attachment.
@return true if the attachment could be found and the viewer program successfully launched;
false otherwise.
*/
- bool view( TQWidget *tqparent, const TQString &attachmentName, ScheduleMessage *message );
+ bool view( TQWidget *parent, const TQString &attachmentName, ScheduleMessage *message );
/**
Saves the specified attachment to a file of the user's choice.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachment is a pointer to a valid Attachment object.
@return true if the save operation was successful; false otherwise.
*/
- bool saveAs( TQWidget *tqparent, Attachment *attachment );
+ bool saveAs( TQWidget *parent, Attachment *attachment );
/**
Saves the specified attachment to a file of the user's choice.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachmentName is the name of the attachment
@param incidence is a pointer to a valid Incidence object containing the attachment.
@return true if the attachment could be found and the save operation was successful;
false otherwise.
*/
- bool saveAs( TQWidget *tqparent, const TQString &attachmentName, Incidence *incidence );
+ bool saveAs( TQWidget *parent, const TQString &attachmentName, Incidence *incidence );
/**
Saves the specified attachment to a file of the user's choice.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachmentName is the name of the attachment
@param uid is a TQString containing a UID of the incidence containing the attachment.
@return true if the attachment could be found and the save operation was successful;
false otherwise.
*/
- bool saveAs( TQWidget *tqparent, const TQString &attachmentName, const TQString &uid );
+ bool saveAs( TQWidget *parent, const TQString &attachmentName, const TQString &uid );
/**
Saves the specified attachment to a file of the user's choice.
- @param tqparent is the tqparent widget for the dialogs used in this function.
+ @param parent is the parent widget for the dialogs used in this function.
@param attachmentName is the name of the attachment
@param message is a pointer to a valid ScheduleMessage object containing the attachment.
@return true if the attachment could be found and the save operation was successful;
false otherwise.
*/
- bool saveAs( TQWidget *tqparent, const TQString &attachmentName, ScheduleMessage *message );
+ bool saveAs( TQWidget *parent, const TQString &attachmentName, ScheduleMessage *message );
}
}
diff --git a/libkcal/calendarresources.cpp b/libkcal/calendarresources.cpp
index df3c1985..abd1cc21 100644
--- a/libkcal/calendarresources.cpp
+++ b/libkcal/calendarresources.cpp
@@ -108,7 +108,7 @@ ResourceCalendar
}
KRES::Resource *r;
- r = KRES::SelectDialog::getResource( list, tqparent() );
+ r = KRES::SelectDialog::getResource( list, parent() );
return static_cast<ResourceCalendar *>( r );
}
@@ -215,12 +215,12 @@ void CalendarResources::setAskDestinationPolicy()
TQWidget *CalendarResources::dialogParentWidget()
{
- return mDestinationPolicy->tqparent();
+ return mDestinationPolicy->parent();
}
-void CalendarResources::setDialogParentWidget( TQWidget *tqparent )
+void CalendarResources::setDialogParentWidget( TQWidget *parent )
{
- mDestinationPolicy->setParent( tqparent );
+ mDestinationPolicy->setParent( parent );
}
void CalendarResources::close()
diff --git a/libkcal/calendarresources.h b/libkcal/calendarresources.h
index 3f601502..1b884b6a 100644
--- a/libkcal/calendarresources.h
+++ b/libkcal/calendarresources.h
@@ -75,12 +75,12 @@ class LIBKCAL_EXPORT CalendarResources :
{
public:
DestinationPolicy( CalendarResourceManager *manager,
- TQWidget *tqparent = 0 ) :
- mManager( manager ), mParent( tqparent ) {}
+ TQWidget *parent = 0 ) :
+ mManager( manager ), mParent( parent ) {}
virtual ResourceCalendar *destination( Incidence *incidence ) = 0;
- virtual TQWidget *tqparent() { return mParent; }
- virtual void setParent( TQWidget *newtqparent ) { mParent = newtqparent; }
+ virtual TQWidget *parent() { return mParent; }
+ virtual void setParent( TQWidget *newparent ) { mParent = newparent; }
bool hasCalendarResources();
protected:
CalendarResourceManager *resourceManager()
@@ -98,8 +98,8 @@ class LIBKCAL_EXPORT CalendarResources :
{
public:
StandardDestinationPolicy( CalendarResourceManager *manager,
- TQWidget *tqparent = 0 ) :
- DestinationPolicy( manager, tqparent ) {}
+ TQWidget *parent = 0 ) :
+ DestinationPolicy( manager, parent ) {}
ResourceCalendar *destination( Incidence *incidence );
@@ -115,8 +115,8 @@ class LIBKCAL_EXPORT CalendarResources :
{
public:
AskDestinationPolicy( CalendarResourceManager *manager,
- TQWidget *tqparent = 0 ) :
- DestinationPolicy( manager, tqparent ) {}
+ TQWidget *parent = 0 ) :
+ DestinationPolicy( manager, parent ) {}
ResourceCalendar *destination( Incidence *incidence );
@@ -271,8 +271,8 @@ class LIBKCAL_EXPORT CalendarResources :
void setAskDestinationPolicy();
/**
- Returns the current tqparent for new dialogs. This is a bad hack, but we need
- to properly set the tqparent for the resource selection dialog. Otherwise
+ Returns the current parent for new dialogs. This is a bad hack, but we need
+ to properly set the parent for the resource selection dialog. Otherwise
the dialog will not be modal to the editor dialog in korganizer and
the user can still work in the editor dialog (and thus crash korganizer).
Afterwards we need to reset it (to avoid pointers to widgets that are
@@ -280,12 +280,12 @@ class LIBKCAL_EXPORT CalendarResources :
*/
TQWidget *dialogParentWidget();
/**
- Set the widget tqparent for new dialogs. This is a bad hack, but we need
- to properly set the tqparent for the resource selection dialog. Otherwise
+ Set the widget parent for new dialogs. This is a bad hack, but we need
+ to properly set the parent for the resource selection dialog. Otherwise
the dialog will not be modal to the editor dialog in korganizer and
the user can still work in the editor dialog (and thus crash korganizer).
*/
- void setDialogParentWidget( TQWidget *tqparent );
+ void setDialogParentWidget( TQWidget *parent );
/**
Request ticket for saving the Calendar. If a ticket is returned the
diff --git a/libkcal/confirmsavedialog.cpp b/libkcal/confirmsavedialog.cpp
index b1e32f32..29834148 100644
--- a/libkcal/confirmsavedialog.cpp
+++ b/libkcal/confirmsavedialog.cpp
@@ -30,8 +30,8 @@
using namespace KCal;
ConfirmSaveDialog::ConfirmSaveDialog( const TQString &destination,
- TQWidget *tqparent, const char *name )
- : KDialogBase( tqparent, name, true, i18n("Confirm Save"), Ok | Cancel )
+ TQWidget *parent, const char *name )
+ : KDialogBase( parent, name, true, i18n("Confirm Save"), Ok | Cancel )
{
TQFrame *topFrame = makeMainWidget();
diff --git a/libkcal/confirmsavedialog.h b/libkcal/confirmsavedialog.h
index cb6a0905..c20a4951 100644
--- a/libkcal/confirmsavedialog.h
+++ b/libkcal/confirmsavedialog.h
@@ -32,7 +32,7 @@ namespace KCal {
class KDE_EXPORT ConfirmSaveDialog : public KDialogBase
{
public:
- ConfirmSaveDialog( const TQString &destination, TQWidget *tqparent,
+ ConfirmSaveDialog( const TQString &destination, TQWidget *parent,
const char *name = 0 );
void addIncidences( const Incidence::List &incidences,
diff --git a/libkcal/icaldrag.cpp b/libkcal/icaldrag.cpp
index 4ff3111a..2c5f2309 100644
--- a/libkcal/icaldrag.cpp
+++ b/libkcal/icaldrag.cpp
@@ -28,8 +28,8 @@
using namespace KCal;
-ICalDrag::ICalDrag( Calendar *cal, TQWidget *tqparent, const char *name )
- : TQStoredDrag( "text/calendar", tqparent, name )
+ICalDrag::ICalDrag( Calendar *cal, TQWidget *parent, const char *name )
+ : TQStoredDrag( "text/calendar", parent, name )
{
ICalFormat icf;
TQString scal = icf.toString( cal );
diff --git a/libkcal/icaldrag.h b/libkcal/icaldrag.h
index b1beb436..ac91742d 100644
--- a/libkcal/icaldrag.h
+++ b/libkcal/icaldrag.h
@@ -38,7 +38,7 @@ class LIBKCAL_EXPORT ICalDrag : public TQStoredDrag
/**
Create a drag&drop object for iCalendar component \a ical.
*/
- ICalDrag( Calendar *cal, TQWidget *tqparent = 0, const char *name = 0 );
+ ICalDrag( Calendar *cal, TQWidget *parent = 0, const char *name = 0 );
~ICalDrag() {};
/**
diff --git a/libkcal/icalformat.cpp b/libkcal/icalformat.cpp
index c427b0df..25feb42f 100644
--- a/libkcal/icalformat.cpp
+++ b/libkcal/icalformat.cpp
@@ -298,9 +298,9 @@ TQString ICalFormat::toString( Incidence *incidence, Calendar *calendar )
icalcomponent *component;
TQString text = "";
- // See if there are any tqparent or child events that must be added to the string
+ // See if there are any parent or child events that must be added to the string
if ( incidence->hasRecurrenceID() ) {
- // Get the tqparent
+ // Get the parent
IncidenceList il = incidence->childIncidences();
IncidenceListIterator it;
it = il.begin();
@@ -319,7 +319,7 @@ TQString ICalFormat::toString( Incidence *incidence, Calendar *calendar )
icalcomponent_free( component );
}
else {
- // This incidence is a potential tqparent
+ // This incidence is a potential parent
IncidenceList il = incidence->childIncidences();
if (il.count() > 0) {
IncidenceListIterator it;
diff --git a/libkcal/icalformatimpl.cpp b/libkcal/icalformatimpl.cpp
index 50879378..bb53a353 100644
--- a/libkcal/icalformatimpl.cpp
+++ b/libkcal/icalformatimpl.cpp
@@ -83,8 +83,8 @@ const int gSecondsPerHour = gSecondsPerMinute * 60;
const int gSecondsPerDay = gSecondsPerHour * 24;
const int gSecondsPerWeek = gSecondsPerDay * 7;
-ICalFormatImpl::ICalFormatImpl( ICalFormat *tqparent ) :
- mParent( tqparent ), mCompat( new Compat )
+ICalFormatImpl::ICalFormatImpl( ICalFormat *parent ) :
+ mParent( parent ), mCompat( new Compat )
{
}
@@ -305,7 +305,7 @@ icalcomponent *ICalFormatImpl::writeJournal(Journal *journal)
return vjournal;
}
-void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence)
+void ICalFormatImpl::writeIncidence(icalcomponent *parent,Incidence *incidence)
{
// pilot sync stuff
// TODO: move this application-specific code to kpilot
@@ -318,17 +318,17 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
icalproperty *p = 0;
p = icalproperty_new_x(TQString::number(incidence->synctqStatus()).utf8());
icalproperty_set_x_name(p,"X-PILOTSTAT");
- icalcomponent_add_property(tqparent,p);
+ icalcomponent_add_property(parent,p);
p = icalproperty_new_x(TQString::number(incidence->pilotId()).utf8());
icalproperty_set_x_name(p,"X-PILOTID");
- icalcomponent_add_property(tqparent,p);
+ icalcomponent_add_property(parent,p);
}
TQString modifiedUid;
if ( incidence->hasRecurrenceID() ) {
- // Recurring incidences are special; they must match their tqparent's UID
- // Each child has the tqparent set as the first item in the list
+ // Recurring incidences are special; they must match their parent's UID
+ // Each child has the parent set as the first item in the list
// So, get and set the UID...
IncidenceList il = incidence->childIncidences();
IncidenceListIterator it;
@@ -346,53 +346,53 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
else
incidence->removeCustomProperty( "LIBKCAL", "ID" );
- writeIncidenceBase(tqparent,incidence);
+ writeIncidenceBase(parent,incidence);
// creation date
- icalcomponent_add_property(tqparent,icalproperty_new_created(
+ icalcomponent_add_property(parent,icalproperty_new_created(
writeICalDateTime(incidence->created())));
// unique id
// If the scheduling ID is different from the real UID, the real
// one is stored on X-REALID above
if ( incidence->hasRecurrenceID() ) {
- // Recurring incidences are special; they must match their tqparent's UID
- icalcomponent_add_property(tqparent,icalproperty_new_uid(modifiedUid.utf8()));
+ // Recurring incidences are special; they must match their parent's UID
+ icalcomponent_add_property(parent,icalproperty_new_uid(modifiedUid.utf8()));
}
else {
if ( !incidence->schedulingID().isEmpty() ) {
- icalcomponent_add_property(tqparent,icalproperty_new_uid(
+ icalcomponent_add_property(parent,icalproperty_new_uid(
incidence->schedulingID().utf8()));
}
}
// revision
if ( incidence->revision() > 0 ) { // 0 is default, so don't write that out
- icalcomponent_add_property(tqparent,icalproperty_new_sequence(
+ icalcomponent_add_property(parent,icalproperty_new_sequence(
incidence->revision()));
}
// last modification date
if ( incidence->lastModified().isValid() ) {
- icalcomponent_add_property(tqparent,icalproperty_new_lastmodified(
+ icalcomponent_add_property(parent,icalproperty_new_lastmodified(
writeICalDateTime(incidence->lastModified())));
}
// description
if (!incidence->description().isEmpty()) {
- icalcomponent_add_property(tqparent,icalproperty_new_description(
+ icalcomponent_add_property(parent,icalproperty_new_description(
incidence->description().utf8()));
}
// summary
if (!incidence->summary().isEmpty()) {
- icalcomponent_add_property(tqparent,icalproperty_new_summary(
+ icalcomponent_add_property(parent,icalproperty_new_summary(
incidence->summary().utf8()));
}
// location
if (!incidence->location().isEmpty()) {
- icalcomponent_add_property(tqparent,icalproperty_new_location(
+ icalcomponent_add_property(parent,icalproperty_new_location(
incidence->location().utf8()));
}
@@ -410,7 +410,7 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
case Incidence::StatusX: {
icalproperty* p = icalproperty_new_status(ICAL_STATUS_X);
icalvalue_set_x(icalproperty_get_value(p), incidence->statusStr().utf8());
- icalcomponent_add_property(tqparent, p);
+ icalcomponent_add_property(parent, p);
break;
}
case Incidence::StatusNone:
@@ -418,7 +418,7 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
break;
}
if (status != ICAL_STATUS_NONE)
- icalcomponent_add_property(tqparent, icalproperty_new_status(status));
+ icalcomponent_add_property(parent, icalproperty_new_status(status));
// secrecy
icalproperty_class secClass;
@@ -435,12 +435,12 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
break;
}
if ( secClass != ICAL_CLASS_PUBLIC ) {
- icalcomponent_add_property(tqparent,icalproperty_new_class(secClass));
+ icalcomponent_add_property(parent,icalproperty_new_class(secClass));
}
// priority
if ( incidence->priority() > 0 ) { // 0 is undefined priority
- icalcomponent_add_property(tqparent,icalproperty_new_priority(
+ icalcomponent_add_property(parent,icalproperty_new_priority(
incidence->priority()));
}
@@ -448,18 +448,18 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
TQStringList categories = incidence->categories();
TQStringList::Iterator it;
for(it = categories.begin(); it != categories.end(); ++it ) {
- icalcomponent_add_property(tqparent,icalproperty_new_categories((*it).utf8()));
+ icalcomponent_add_property(parent,icalproperty_new_categories((*it).utf8()));
}
// related event
if ( !incidence->relatedToUid().isEmpty() ) {
- icalcomponent_add_property(tqparent,icalproperty_new_relatedto(
+ icalcomponent_add_property(parent,icalproperty_new_relatedto(
incidence->relatedToUid().utf8()));
}
// recurrenceid
if ( incidence->hasRecurrenceID() ) {
- icalcomponent_add_property(tqparent, icalproperty_new_recurrenceid( writeICalDateTime( incidence->recurrenceID() ) ));
+ icalcomponent_add_property(parent, icalproperty_new_recurrenceid( writeICalDateTime( incidence->recurrenceID() ) ));
}
// kdDebug(5800) << "Write recurrence for '" << incidence->summary() << "' (" << incidence->uid()
@@ -468,27 +468,27 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
RecurrenceRule::List rrules( incidence->recurrence()->rRules() );
RecurrenceRule::List::ConstIterator rit;
for ( rit = rrules.begin(); rit != rrules.end(); ++rit ) {
- icalcomponent_add_property( tqparent, icalproperty_new_rrule(
+ icalcomponent_add_property( parent, icalproperty_new_rrule(
writeRecurrenceRule( (*rit) ) ) );
}
RecurrenceRule::List exrules( incidence->recurrence()->exRules() );
RecurrenceRule::List::ConstIterator exit;
for ( exit = exrules.begin(); exit != exrules.end(); ++exit ) {
- icalcomponent_add_property( tqparent, icalproperty_new_rrule(
+ icalcomponent_add_property( parent, icalproperty_new_rrule(
writeRecurrenceRule( (*exit) ) ) );
}
DateList dateList = incidence->recurrence()->exDates();
DateList::ConstIterator exIt;
for(exIt = dateList.begin(); exIt != dateList.end(); ++exIt) {
- icalcomponent_add_property(tqparent,icalproperty_new_exdate(
+ icalcomponent_add_property(parent,icalproperty_new_exdate(
writeICalDate(*exIt)));
}
DateTimeList dateTimeList = incidence->recurrence()->exDateTimes();
DateTimeList::ConstIterator extIt;
for(extIt = dateTimeList.begin(); extIt != dateTimeList.end(); ++extIt) {
- icalcomponent_add_property(tqparent,icalproperty_new_exdate(
+ icalcomponent_add_property(parent,icalproperty_new_exdate(
writeICalDateTime(*extIt)));
}
@@ -496,13 +496,13 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
dateList = incidence->recurrence()->rDates();
DateList::ConstIterator rdIt;
for( rdIt = dateList.begin(); rdIt != dateList.end(); ++rdIt) {
- icalcomponent_add_property( tqparent, icalproperty_new_rdate(
+ icalcomponent_add_property( parent, icalproperty_new_rdate(
writeICalDatePeriod(*rdIt) ) );
}
dateTimeList = incidence->recurrence()->rDateTimes();
DateTimeList::ConstIterator rdtIt;
for( rdtIt = dateTimeList.begin(); rdtIt != dateTimeList.end(); ++rdtIt) {
- icalcomponent_add_property( tqparent, icalproperty_new_rdate(
+ icalcomponent_add_property( parent, icalproperty_new_rdate(
writeICalDateTimePeriod(*rdtIt) ) );
}
@@ -510,7 +510,7 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
Attachment::List attachments = incidence->attachments();
Attachment::List::ConstIterator atIt;
for ( atIt = attachments.begin(); atIt != attachments.end(); ++atIt ) {
- icalcomponent_add_property( tqparent, writeAttachment( *atIt ) );
+ icalcomponent_add_property( parent, writeAttachment( *atIt ) );
}
// alarms
@@ -519,7 +519,7 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
alarmIt != incidence->alarms().end(); ++alarmIt ) {
if ( (*alarmIt)->enabled() ) {
// kdDebug(5800) << "Write alarm for " << incidence->summary() << endl;
- icalcomponent_add_component( tqparent, writeAlarm( *alarmIt ) );
+ icalcomponent_add_component( parent, writeAlarm( *alarmIt ) );
}
}
@@ -527,19 +527,19 @@ void ICalFormatImpl::writeIncidence(icalcomponent *tqparent,Incidence *incidence
if (incidence->hasDuration()) {
icaldurationtype duration;
duration = writeICalDuration( incidence->duration() );
- icalcomponent_add_property(tqparent,icalproperty_new_duration(duration));
+ icalcomponent_add_property(parent,icalproperty_new_duration(duration));
}
}
-void ICalFormatImpl::writeIncidenceBase( icalcomponent *tqparent,
+void ICalFormatImpl::writeIncidenceBase( icalcomponent *parent,
IncidenceBase * incidenceBase )
{
- icalcomponent_add_property( tqparent, icalproperty_new_dtstamp(
+ icalcomponent_add_property( parent, icalproperty_new_dtstamp(
writeICalDateTime( TQDateTime::tqcurrentDateTime() ) ) );
// organizer stuff
if ( !incidenceBase->organizer().isEmpty() ) {
- icalcomponent_add_property( tqparent, writeOrganizer( incidenceBase->organizer() ) );
+ icalcomponent_add_property( parent, writeOrganizer( incidenceBase->organizer() ) );
}
// attendees
@@ -547,27 +547,27 @@ void ICalFormatImpl::writeIncidenceBase( icalcomponent *tqparent,
Attendee::List::ConstIterator it;
for( it = incidenceBase->attendees().begin();
it != incidenceBase->attendees().end(); ++it ) {
- icalcomponent_add_property( tqparent, writeAttendee( *it ) );
+ icalcomponent_add_property( parent, writeAttendee( *it ) );
}
}
// comments
TQStringList comments = incidenceBase->comments();
for (TQStringList::Iterator it=comments.begin(); it!=comments.end(); ++it) {
- icalcomponent_add_property(tqparent, icalproperty_new_comment((*it).utf8()));
+ icalcomponent_add_property(parent, icalproperty_new_comment((*it).utf8()));
}
// custom properties
- writeCustomProperties( tqparent, incidenceBase );
+ writeCustomProperties( parent, incidenceBase );
}
-void ICalFormatImpl::writeCustomProperties(icalcomponent *tqparent,CustomProperties *properties)
+void ICalFormatImpl::writeCustomProperties(icalcomponent *parent,CustomProperties *properties)
{
TQMap<TQCString, TQString> custom = properties->customProperties();
for (TQMap<TQCString, TQString>::Iterator c = custom.begin(); c != custom.end(); ++c) {
icalproperty *p = icalproperty_new_x(c.data().utf8());
icalproperty_set_x_name(p,c.key());
- icalcomponent_add_property(tqparent,p);
+ icalcomponent_add_property(parent,p);
}
}
@@ -970,7 +970,7 @@ Todo *ICalFormatImpl::readTodo(icalcomponent *vtodo)
todo->setPercentComplete(icalproperty_get_percentcomplete(p));
break;
- case ICAL_RELATEDTO_PROPERTY: // related todo (tqparent)
+ case ICAL_RELATEDTO_PROPERTY: // related todo (parent)
todo->setRelatedToUid(TQString::fromUtf8(icalproperty_get_relatedto(p)));
mTodosRelate.append(todo);
break;
@@ -1050,7 +1050,7 @@ Event *ICalFormatImpl::readEvent( icalcomponent *vevent, icalcomponent *vtimezon
dtEndProcessed = true;
break;
- case ICAL_RELATEDTO_PROPERTY: // related event (tqparent)
+ case ICAL_RELATEDTO_PROPERTY: // related event (parent)
event->setRelatedToUid( TQString::fromUtf8( icalproperty_get_relatedto( p ) ) );
mEventsRelate.append( event );
break;
@@ -1356,11 +1356,11 @@ Attachment *ICalFormatImpl::readAttachment(icalproperty *attach)
return attachment;
}
-void ICalFormatImpl::readIncidence(icalcomponent *tqparent, icaltimezone *tz, Incidence *incidence)
+void ICalFormatImpl::readIncidence(icalcomponent *parent, icaltimezone *tz, Incidence *incidence)
{
- readIncidenceBase(tqparent,incidence);
+ readIncidenceBase(parent,incidence);
- icalproperty *p = icalcomponent_get_first_property(tqparent,ICAL_ANY_PROPERTY);
+ icalproperty *p = icalcomponent_get_first_property(parent,ICAL_ANY_PROPERTY);
const char *text;
int intvalue, inttext;
@@ -1516,7 +1516,7 @@ void ICalFormatImpl::readIncidence(icalcomponent *tqparent, icaltimezone *tz, In
break;
}
- p = icalcomponent_get_next_property(tqparent,ICAL_ANY_PROPERTY);
+ p = icalcomponent_get_next_property(parent,ICAL_ANY_PROPERTY);
}
// Set the scheduling ID
@@ -1538,9 +1538,9 @@ void ICalFormatImpl::readIncidence(icalcomponent *tqparent, icaltimezone *tz, In
incidence->setCategories(categories);
// iterate through all alarms
- for (icalcomponent *alarm = icalcomponent_get_first_component(tqparent,ICAL_VALARM_COMPONENT);
+ for (icalcomponent *alarm = icalcomponent_get_first_component(parent,ICAL_VALARM_COMPONENT);
alarm;
- alarm = icalcomponent_get_next_component(tqparent,ICAL_VALARM_COMPONENT)) {
+ alarm = icalcomponent_get_next_component(parent,ICAL_VALARM_COMPONENT)) {
readAlarm(alarm,incidence);
}
// Fix incorrect alarm settings by other applications (like outloook 9)
@@ -1548,9 +1548,9 @@ void ICalFormatImpl::readIncidence(icalcomponent *tqparent, icaltimezone *tz, In
}
-void ICalFormatImpl::readIncidenceBase(icalcomponent *tqparent,IncidenceBase *incidenceBase)
+void ICalFormatImpl::readIncidenceBase(icalcomponent *parent,IncidenceBase *incidenceBase)
{
- icalproperty *p = icalcomponent_get_first_property(tqparent,ICAL_ANY_PROPERTY);
+ icalproperty *p = icalcomponent_get_first_property(parent,ICAL_ANY_PROPERTY);
bool uidProcessed = false;
@@ -1580,7 +1580,7 @@ void ICalFormatImpl::readIncidenceBase(icalcomponent *tqparent,IncidenceBase *in
break;
}
- p = icalcomponent_get_next_property( tqparent, ICAL_ANY_PROPERTY );
+ p = icalcomponent_get_next_property( parent, ICAL_ANY_PROPERTY );
}
if ( !uidProcessed ) {
@@ -1604,35 +1604,35 @@ void ICalFormatImpl::readIncidenceBase(icalcomponent *tqparent,IncidenceBase *in
// (documented in UsingLibical.txt)
icalproperty *next =0;
- for ( p = icalcomponent_get_first_property(tqparent,ICAL_X_PROPERTY);
+ for ( p = icalcomponent_get_first_property(parent,ICAL_X_PROPERTY);
p != 0;
p = next )
{
- next = icalcomponent_get_next_property(tqparent,ICAL_X_PROPERTY);
+ next = icalcomponent_get_next_property(parent,ICAL_X_PROPERTY);
TQString value = TQString::fromUtf8(icalproperty_get_x(p));
TQString name = icalproperty_get_x_name(p);
if (name == "X-PILOTID" && !value.isEmpty()) {
incidenceBase->setPilotId(value.toInt());
- icalcomponent_remove_property(tqparent,p);
+ icalcomponent_remove_property(parent,p);
} else if (name == "X-PILOTSTAT" && !value.isEmpty()) {
incidenceBase->setSynctqStatus(value.toInt());
- icalcomponent_remove_property(tqparent,p);
+ icalcomponent_remove_property(parent,p);
}
}
// custom properties
- readCustomProperties(tqparent, incidenceBase);
+ readCustomProperties(parent, incidenceBase);
}
-void ICalFormatImpl::readCustomProperties(icalcomponent *tqparent,CustomProperties *properties)
+void ICalFormatImpl::readCustomProperties(icalcomponent *parent,CustomProperties *properties)
{
TQMap<TQCString, TQString> customProperties;
TQString lastProperty;
- icalproperty *p = icalcomponent_get_first_property(tqparent,ICAL_X_PROPERTY);
+ icalproperty *p = icalcomponent_get_first_property(parent,ICAL_X_PROPERTY);
while (p) {
@@ -1644,7 +1644,7 @@ void ICalFormatImpl::readCustomProperties(icalcomponent *tqparent,CustomProperti
customProperties[name] = customProperties[name].append( "," ).append( value );
}
// kdDebug(5800) << "Set custom property [" << name << '=' << value << ']' << endl;
- p = icalcomponent_get_next_property(tqparent,ICAL_X_PROPERTY);
+ p = icalcomponent_get_next_property(parent,ICAL_X_PROPERTY);
lastProperty = name;
}
@@ -2177,9 +2177,9 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar )
printf("FIXME! [WARNING] Parent for child event does not yet exist!\n\r");
}
else {
- // Add this todo to its tqparent
+ // Add this todo to its parent
cal->todo(originalUid)->addChildIncidence(todo->uid());
- // And the tqparent to the child
+ // And the parent to the child
todo->addChildIncidence(cal->todo(originalUid)->uid());
}
}
@@ -2215,9 +2215,9 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar )
printf("FIXME! [WARNING] Parent for child event does not yet exist!\n\r");
}
else {
- // Add this event to its tqparent
+ // Add this event to its parent
cal->event(originalUid)->addChildIncidence(event->uid());
- // And the tqparent to the child
+ // And the parent to the child
event->addChildIncidence(cal->event(originalUid)->uid());
}
}
@@ -2253,9 +2253,9 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar )
printf("FIXME! [WARNING] Parent for child event does not yet exist!\n\r");
}
else {
- // Add this journal to its tqparent
+ // Add this journal to its parent
cal->journal(originalUid)->addChildIncidence(journal->uid());
- // And the tqparent to the child
+ // And the parent to the child
journal->addChildIncidence(cal->journal(originalUid)->uid());
}
}
diff --git a/libkcal/icalformatimpl.h b/libkcal/icalformatimpl.h
index 215adfe9..9a2e9f62 100644
--- a/libkcal/icalformatimpl.h
+++ b/libkcal/icalformatimpl.h
@@ -46,7 +46,7 @@ class ICalFormatImpl
{
public:
/** Create new iCal format for calendar object */
- ICalFormatImpl( ICalFormat *tqparent );
+ ICalFormatImpl( ICalFormat *parent );
virtual ~ICalFormatImpl();
bool populate( Calendar *, icalcomponent *fs);
@@ -57,7 +57,7 @@ class ICalFormatImpl
icalcomponent *writeFreeBusy(FreeBusy *freebusy,
Scheduler::Method method = Scheduler::Publish );
icalcomponent *writeJournal(Journal *journal);
- void writeIncidence(icalcomponent *tqparent,Incidence *incidence);
+ void writeIncidence(icalcomponent *parent,Incidence *incidence);
icalproperty *writeAttendee(Attendee *attendee);
icalproperty *writeOrganizer( const Person &organizer );
icalproperty *writeAttachment(Attachment *attach);
@@ -73,7 +73,7 @@ class ICalFormatImpl
Attendee *readAttendee(icalproperty *attendee);
Person readOrganizer( icalproperty *organizer );
Attachment *readAttachment(icalproperty *attach);
- void readIncidence(icalcomponent *tqparent, icaltimezone *timezone, Incidence *incidence);
+ void readIncidence(icalcomponent *parent, icaltimezone *timezone, Incidence *incidence);
void readRecurrenceRule(icalproperty *rrule,Incidence *event );
void readExceptionRule( icalproperty *rrule, Incidence *incidence );
void readRecurrence( const struct icalrecurrencetype &r, RecurrenceRule* recur );
@@ -96,10 +96,10 @@ class ICalFormatImpl
protected:
void dumpIcalRecurrence(icalrecurrencetype);
private:
- void writeIncidenceBase(icalcomponent *tqparent,IncidenceBase *);
- void readIncidenceBase(icalcomponent *tqparent, IncidenceBase *);
- void writeCustomProperties(icalcomponent *tqparent,CustomProperties *);
- void readCustomProperties(icalcomponent *tqparent,CustomProperties *);
+ void writeIncidenceBase(icalcomponent *parent,IncidenceBase *);
+ void readIncidenceBase(icalcomponent *parent, IncidenceBase *);
+ void writeCustomProperties(icalcomponent *parent,CustomProperties *);
+ void readCustomProperties(icalcomponent *parent,CustomProperties *);
void readTimezone(icalcomponent *vtimezone);
ICalFormat *mParent;
diff --git a/libkcal/incidence.h b/libkcal/incidence.h
index bfb883fd..8b6ddd1a 100644
--- a/libkcal/incidence.h
+++ b/libkcal/incidence.h
@@ -459,14 +459,14 @@ class LIBKCAL_EXPORT Incidence : public IncidenceBase, public Recurrence::Observ
TQDateTime recurrenceID() const;
/**
- Attach a child incidence to a tqparent incidence.
+ Attach a child incidence to a parent incidence.
@param childIncidence is the child incidence to add
@since 3.5.12
*/
void addChildIncidence( TQString childIncidence );
/**
- Detach a child incidence from its tqparent incidence.
+ Detach a child incidence from its parent incidence.
@param childIncidence is the child incidence to remove
@since 3.5.12
*/
diff --git a/libkcal/recurrence.h b/libkcal/recurrence.h
index f50be8bd..122e6d62 100644
--- a/libkcal/recurrence.h
+++ b/libkcal/recurrence.h
@@ -308,7 +308,7 @@ class LIBKCAL_EXPORT Recurrence : public RecurrenceRule::Observer
* @return Weekday of the first day of the week (Monday=1 .. Sunday=7)
*/
int weekStart() const;
- /** Returns week day tqmask (bit 0 = Monday). */
+ /** Returns week day mask (bit 0 = Monday). */
TQBitArray days() const; // Emulate the old behavior
/** Sets an event to recur monthly. By default infinite recurrence is used.
diff --git a/libkcal/recurrencerule.h b/libkcal/recurrencerule.h
index 14335a0b..4d813907 100644
--- a/libkcal/recurrencerule.h
+++ b/libkcal/recurrencerule.h
@@ -199,7 +199,7 @@ class LIBKCAL_EXPORT RecurrenceRule
// Bounded by -366 and +366, 0 means all weeks in that period
};
- RecurrenceRule( /*Incidence *tqparent, int compatVersion = 0*/ );
+ RecurrenceRule( /*Incidence *parent, int compatVersion = 0*/ );
RecurrenceRule(const RecurrenceRule&);
~RecurrenceRule();
@@ -207,7 +207,7 @@ class LIBKCAL_EXPORT RecurrenceRule
bool operator!=( const RecurrenceRule& r ) const { return !operator==(r); }
RecurrenceRule &operator=(const RecurrenceRule&);
-// Incidence *tqparent() const { return mParent; }
+// Incidence *parent() const { return mParent; }
/** Set if recurrence is read-only or can be changed. */
diff --git a/libkcal/resourcecached.cpp b/libkcal/resourcecached.cpp
index 0e9f3405..bab09728 100644
--- a/libkcal/resourcecached.cpp
+++ b/libkcal/resourcecached.cpp
@@ -518,8 +518,8 @@ void ResourceCached::calendarIncidenceDeleted( Incidence *i )
#endif
if (i->hasRecurrenceID()) {
- // This incidence has a tqparent; notify the tqparent of the child's death and do not destroy the tqparent!
- // Get the tqparent
+ // This incidence has a parent; notify the parent of the child's death and do not destroy the parent!
+ // Get the parent
IncidenceList il = i->childIncidences();
IncidenceListIterator it;
it = il.begin();
diff --git a/libkcal/resourcecachedconfig.cpp b/libkcal/resourcecachedconfig.cpp
index b230f5bb..caa1fddf 100644
--- a/libkcal/resourcecachedconfig.cpp
+++ b/libkcal/resourcecachedconfig.cpp
@@ -35,9 +35,9 @@
using namespace KCal;
-ResourceCachedReloadConfig::ResourceCachedReloadConfig( TQWidget *tqparent,
+ResourceCachedReloadConfig::ResourceCachedReloadConfig( TQWidget *parent,
const char *name )
- : TQWidget( tqparent, name )
+ : TQWidget( parent, name )
{
TQBoxLayout *topLayout = new TQVBoxLayout( this );
@@ -75,9 +75,9 @@ void ResourceCachedReloadConfig::slotIntervalStateChanged( int state )
}
-ResourceCachedSaveConfig::ResourceCachedSaveConfig( TQWidget *tqparent,
+ResourceCachedSaveConfig::ResourceCachedSaveConfig( TQWidget *parent,
const char *name )
- : TQWidget( tqparent, name )
+ : TQWidget( parent, name )
{
TQBoxLayout *topLayout = new TQVBoxLayout( this );
diff --git a/libkcal/resourcecachedconfig.h b/libkcal/resourcecachedconfig.h
index 16364f42..13ea648b 100644
--- a/libkcal/resourcecachedconfig.h
+++ b/libkcal/resourcecachedconfig.h
@@ -41,7 +41,7 @@ class KDE_EXPORT ResourceCachedReloadConfig : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- ResourceCachedReloadConfig( TQWidget *tqparent = 0, const char *name = 0 );
+ ResourceCachedReloadConfig( TQWidget *parent = 0, const char *name = 0 );
public slots:
void loadSettings( ResourceCached *resource );
@@ -68,7 +68,7 @@ class KDE_EXPORT ResourceCachedSaveConfig : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- ResourceCachedSaveConfig( TQWidget *tqparent = 0, const char *name = 0 );
+ ResourceCachedSaveConfig( TQWidget *parent = 0, const char *name = 0 );
public slots:
void loadSettings( ResourceCached *resource );
diff --git a/libkcal/resourcelocalconfig.cpp b/libkcal/resourcelocalconfig.cpp
index 29d879da..e237037c 100644
--- a/libkcal/resourcelocalconfig.cpp
+++ b/libkcal/resourcelocalconfig.cpp
@@ -40,8 +40,8 @@
using namespace KCal;
-ResourceLocalConfig::ResourceLocalConfig( TQWidget* tqparent, const char* name )
- : KRES::ConfigWidget( tqparent, name )
+ResourceLocalConfig::ResourceLocalConfig( TQWidget* parent, const char* name )
+ : KRES::ConfigWidget( parent, name )
{
resize( 245, 115 );
TQGridLayout *mainLayout = new TQGridLayout( this, 2, 2 );
diff --git a/libkcal/resourcelocalconfig.h b/libkcal/resourcelocalconfig.h
index fbd0d00f..f6cba16f 100644
--- a/libkcal/resourcelocalconfig.h
+++ b/libkcal/resourcelocalconfig.h
@@ -44,7 +44,7 @@ class LIBKCAL_EXPORT ResourceLocalConfig : public KRES::ConfigWidget
Q_OBJECT
TQ_OBJECT
public:
- ResourceLocalConfig( TQWidget* tqparent = 0, const char* name = 0 );
+ ResourceLocalConfig( TQWidget* parent = 0, const char* name = 0 );
public slots:
virtual void loadSettings( KRES::Resource *resource);
diff --git a/libkcal/resourcelocaldirconfig.cpp b/libkcal/resourcelocaldirconfig.cpp
index 263d1ce2..df2412b3 100644
--- a/libkcal/resourcelocaldirconfig.cpp
+++ b/libkcal/resourcelocaldirconfig.cpp
@@ -39,8 +39,8 @@
using namespace KCal;
-ResourceLocalDirConfig::ResourceLocalDirConfig( TQWidget* tqparent, const char* name )
- : KRES::ConfigWidget( tqparent, name )
+ResourceLocalDirConfig::ResourceLocalDirConfig( TQWidget* parent, const char* name )
+ : KRES::ConfigWidget( parent, name )
{
resize( 245, 115 );
TQGridLayout *mainLayout = new TQGridLayout( this, 2, 2 );
diff --git a/libkcal/resourcelocaldirconfig.h b/libkcal/resourcelocaldirconfig.h
index df1e682b..3866e9cc 100644
--- a/libkcal/resourcelocaldirconfig.h
+++ b/libkcal/resourcelocaldirconfig.h
@@ -46,7 +46,7 @@ class LIBKCAL_EXPORT ResourceLocalDirConfig : public KRES::ConfigWidget
Q_OBJECT
TQ_OBJECT
public:
- ResourceLocalDirConfig( TQWidget *tqparent = 0, const char *name = 0 );
+ ResourceLocalDirConfig( TQWidget *parent = 0, const char *name = 0 );
public slots:
virtual void loadSettings( KRES::Resource *resource);
diff --git a/libkcal/scheduler.cpp b/libkcal/scheduler.cpp
index 481a33a6..e4f03a01 100644
--- a/libkcal/scheduler.cpp
+++ b/libkcal/scheduler.cpp
@@ -330,13 +330,13 @@ bool Scheduler::acceptRequest( IncidenceBase *incidence,
return false;
}
- // FIXME: This is a nasty hack, since we need to set a tqparent for the
+ // FIXME: This is a nasty hack, since we need to set a parent for the
// resource selection dialog. However, we don't have any UI methods
// in the calendar, only in the CalendarResources::DestinationPolicy
// So we need to type-cast it and extract it from the CalendarResources
- TQWidget *tmptqparent = 0;
+ TQWidget *tmpparent = 0;
if ( stdcal ) {
- tmptqparent = stdcal->dialogParentWidget();
+ tmpparent = stdcal->dialogParentWidget();
stdcal->setDialogParentWidget( 0 );
}
diff --git a/libkcal/vcaldrag.cpp b/libkcal/vcaldrag.cpp
index 590263ab..853c5187 100644
--- a/libkcal/vcaldrag.cpp
+++ b/libkcal/vcaldrag.cpp
@@ -26,8 +26,8 @@
using namespace KCal;
-VCalDrag::VCalDrag( Calendar *cal, TQWidget *tqparent, const char *name )
- : TQStoredDrag( "text/x-vCalendar", tqparent, name )
+VCalDrag::VCalDrag( Calendar *cal, TQWidget *parent, const char *name )
+ : TQStoredDrag( "text/x-vCalendar", parent, name )
{
VCalFormat format;
setEncodedData( format.toString( cal ).utf8() );
diff --git a/libkcal/vcaldrag.h b/libkcal/vcaldrag.h
index c139827a..7cb8c6bb 100644
--- a/libkcal/vcaldrag.h
+++ b/libkcal/vcaldrag.h
@@ -38,7 +38,7 @@ class KDE_EXPORT VCalDrag : public TQStoredDrag
/**
Create a drag&drop object for vCalendar component \a vcal.
*/
- VCalDrag( Calendar *vcal, TQWidget *tqparent = 0, const char *name = 0 );
+ VCalDrag( Calendar *vcal, TQWidget *parent = 0, const char *name = 0 );
~VCalDrag() {}
/**
diff --git a/libkcal/versit/readme.txt b/libkcal/versit/readme.txt
index c03ba9b5..e51acb6d 100644
--- a/libkcal/versit/readme.txt
+++ b/libkcal/versit/readme.txt
@@ -229,9 +229,9 @@ VObject tree can be pretty printed with the printVObject() function.
The output of pretty printing a VObject representation of the input
test file "vobject.vcf" is shown below. Note that the indentation
indicates the tree hirerarchy where the immediate tqchildren nodes
-of a tqparent node is all at the same indentation level and the
+of a parent node is all at the same indentation level and the
immediate tqchildren nodes are the immediate properties of the
-associated tqparent nodes. In the following, {N,FN,ORG,TITLE,...}
+associated parent nodes. In the following, {N,FN,ORG,TITLE,...}
are immediate properties of VCARD. {F and G} are properties of N
with value {"Alden" and "Roland"} respectively; FN has no property
but has the value "Roland H. Alden"; EMAIL has value and
diff --git a/libkcal/calendar.cpp b/libkcal/calendar.cpp
index 4ff7137e..897e9017 100644
--- a/libkcal/calendar.cpp
+++ b/libkcal/calendar.cpp
@@ -474,7 +474,7 @@ bool Calendar::deleteIncidence( Incidence *incidence )
{
if ( beginChange( incidence ) ) {
if (incidence->hasRecurrenceID()) {
// Delete this event's UID from the tqparent's list of tqchildren
Incidence *parentIncidence;
IncidenceList il = incidence->childIncidences();
IncidenceListIterator it;
@@ -841,7 +841,7 @@ void Calendar::setupRelations( Incidence *forincidence )
// kdDebug(5850) << "Calendar::setupRelations for incidence " << forincidence << " with UID " << forincidence->uid() << ", summary: " << forincidence->summary() << endl;
TQString uid = forincidence->uid();
// First, go over the list of orphans and see if this is their tqparent
while ( Incidence* i = mOrphans[ uid ] ) {
mOrphans.remove( uid );
i->setRelatedTo( forincidence );
@@ -849,19 +849,19 @@ void Calendar::setupRelations( Incidence *forincidence )
mOrphanUids.remove( i->uid() );
}
// Now see about this incidences tqparent
if ( !forincidence->relatedTo() && !forincidence->relatedToUid().isEmpty() ) {
// This incidence has a uid it is related to but is not registered to it yet
// Try to find it
- Incidence* tqparent = incidence( forincidence->relatedToUid() );
- if ( tqparent ) {
+ Incidence* parent = incidence( forincidence->relatedToUid() );
+ if ( parent ) {
// Found it
- forincidence->setRelatedTo( tqparent );
- tqparent->addRelation( forincidence );
+ forincidence->setRelatedTo( parent );
+ parent->addRelation( forincidence );
} else {
// Not found, put this in the mOrphans list
// Note that the mOrphans dict might have several entries with the same key! That are
// multiple tqchildren that wait for the tqparent incidence to be inserted.
mOrphans.insert( forincidence->relatedToUid(), forincidence );
mOrphanUids.insert( forincidence->uid(), forincidence );
}
@@ -901,10 +901,10 @@ void Calendar::removeRelations( Incidence *incidence )
// Since the mOrphans dict might contain the same key (with different
// child incidence pointers!) multiple times, take care that we remove
// the correct one. So we need to remove all items with the given
// tqparent UID, and readd those that are not for this item. Also, there
// might be other entries with differnet UID that point to this
// incidence (this might happen when the relatedTo of the item is
// changed before its tqparent is inserted. This might happen with
// groupware servers....). Remove them, too
TQStringList relatedToUids;
// First get the list of all keys in the mOrphans list that point to the removed item
@@ -474,7 +474,7 @@ bool Calendar::deleteIncidence( Incidence *incidence )
if ( beginChange( incidence ) ) {
if (incidence->hasRecurrenceID()) {
- // Delete this event's UID from the tqparent's list of tqchildren
+ // Delete this event's UID from the parent's list of tqchildren
Incidence *parentIncidence;
IncidenceList il = incidence->childIncidences();
@@ -841,7 +841,7 @@ void Calendar::setupRelations( Incidence *forincidence )
// kdDebug(5850) << "Calendar::setupRelations for incidence " << forincidence << " with UID " << forincidence->uid() << ", summary: " << forincidence->summary() << endl;
TQString uid = forincidence->uid();
- // First, go over the list of orphans and see if this is their tqparent
+ // First, go over the list of orphans and see if this is their parent
while ( Incidence* i = mOrphans[ uid ] ) {
mOrphans.remove( uid );
@@ -849,19 +849,19 @@ void Calendar::setupRelations( Incidence *forincidence )
mOrphanUids.remove( i->uid() );
}
- // Now see about this incidences tqparent
+ // Now see about this incidences parent
if ( !forincidence->relatedTo() && !forincidence->relatedToUid().isEmpty() ) {
// This incidence has a uid it is related to but is not registered to it yet
@@ -849,19 +849,19 @@ void Calendar::setupRelations( Incidence *forincidence )
// Not found, put this in the mOrphans list
// Note that the mOrphans dict might have several entries with the same key! That are
- // multiple tqchildren that wait for the tqparent incidence to be inserted.
+ // multiple tqchildren that wait for the parent incidence to be inserted.
mOrphans.insert( forincidence->relatedToUid(), forincidence );
mOrphanUids.insert( forincidence->uid(), forincidence );
@@ -901,10 +901,10 @@ void Calendar::removeRelations( Incidence *incidence )
// child incidence pointers!) multiple times, take care that we remove
// the correct one. So we need to remove all items with the given
- // tqparent UID, and readd those that are not for this item. Also, there
+ // parent UID, and readd those that are not for this item. Also, there
// might be other entries with differnet UID that point to this
// incidence (this might happen when the relatedTo of the item is
@@ -901,10 +901,10 @@ void Calendar::removeRelations( Incidence *incidence )
// might be other entries with differnet UID that point to this
// incidence (this might happen when the relatedTo of the item is
- // changed before its tqparent is inserted. This might happen with
+ // changed before its parent is inserted. This might happen with
// groupware servers....). Remove them, too
TQStringList relatedToUids;
diff --git a/libkcal/resourcecalendar.h b/libkcal/resourcecalendar.h
index 03318737..ef1acb2d 100644
--- a/libkcal/resourcecalendar.h
+++ b/libkcal/resourcecalendar.h
@@ -386,10 +386,10 @@ class LIBKCAL_EXPORT ResourceCalendar : public KRES::Resource
virtual bool removeSubresource( const TQString& resource );
/**
* Add a subresource with the name @param resource and the tqparent
* id @param tqparent.
*/
- virtual bool addSubresource( const TQString& resource, const TQString& tqparent );
+ virtual bool addSubresource( const TQString& resource, const TQString& parent );
/**
* Returns the type of the subresource: "event", "todo" or "journal",
@@ -386,10 +386,10 @@ class LIBKCAL_EXPORT ResourceCalendar : public KRES::Resource
virtual bool removeSubresource( const TQString& resource );
/**
- * Add a subresource with the name @param resource and the tqparent
- * id @param tqparent.
+ * Add a subresource with the name @param resource and the parent
+ * id @param parent.
*/